Getting help
=============

If you have any problems or questions, please don't hesitate to contact me by email:
**ekaterina.e.noskova@gmail.com**. I will be glad to answer your questions.

Also you are always welcome to `create an issue <https://github.com/ctlab/GADMA/issues/new>`_ on the `GitHub page <https://github.com/ctlab/GADMA>`_ of GADMA with your question.

